==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/FormatGroupTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatGroupTextEventArgsDescription } from "./FormatGroupTextEventArgsDescription";
/**
 * @hidden
 */
var FormatGroupTextEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FormatGroupTextEventArgsDescriptionMetadata, _super);
    function FormatGroupTextEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatGroupTextEventArgsDescriptionMetadata.b = function (a) {
        if (FormatGroupTextEventArgsDescriptionMetadata.a == null) {
            FormatGroupTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatGroupTextEventArgsDescriptionMetadata.c(FormatGroupTextEventArgsDescriptionMetadata.a);
        }
        if (a.g(FormatGroupTextEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(FormatGroupTextEventArgsDescriptionMetadata.a);
    };
    FormatGroupTextEventArgsDescriptionMetadata.c = function (a) {
        a.item("GroupName", "String");
        a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
        a.item("FormattedValue", "String");
        a.item("FormattedText", "String");
    };
    FormatGroupTextEventArgsDescriptionMetadata.d = function (a) {
        FormatGroupTextEventArgsDescriptionMetadata.b(a);
        a.u("FormatGroupTextEventArgs", function () { return new FormatGroupTextEventArgsDescription(); });
        a.t("FormatGroupTextEventArgs", FormatGroupTextEventArgsDescriptionMetadata.a);
    };
    FormatGroupTextEventArgsDescriptionMetadata.$t = markType(FormatGroupTextEventArgsDescriptionMetadata, 'FormatGroupTextEventArgsDescriptionMetadata');
    FormatGroupTextEventArgsDescriptionMetadata.a = null;
    return FormatGroupTextEventArgsDescriptionMetadata;
}(Base));
export { FormatGroupTextEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/FormatGroupTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatGroupTextEventArgsDescription } from "./FormatGroupTextEventArgsDescription";
/**
 * @hidden
 */
var FormatGroupTextEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FormatGroupTextEventArgsDescriptionMetadata, _super);
    function FormatGroupTextEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatGroupTextEventArgsDescriptionMetadata.b = function (a) {
        if (FormatGroupTextEventArgsDescriptionMetadata.a == null) {
            FormatGroupTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatGroupTextEventArgsDescriptionMetadata.c(FormatGroupTextEventArgsDescriptionMetadata.a);
        }
        if (a.j(FormatGroupTextEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(FormatGroupTextEventArgsDescriptionMetadata.a);
    };
    FormatGroupTextEventArgsDescriptionMetadata.c = function (a) {
        a.item("GroupName", "String");
        a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
        a.item("FormattedValue", "String");
        a.item("FormattedText", "String");
    };
    FormatGroupTextEventArgsDescriptionMetadata.d = function (a) {
        FormatGroupTextEventArgsDescriptionMetadata.b(a);
        a.aa("FormatGroupTextEventArgs", function () { return new FormatGroupTextEventArgsDescription(); });
        a.z("FormatGroupTextEventArgs", FormatGroupTextEventArgsDescriptionMetadata.a);
    };
    FormatGroupTextEventArgsDescriptionMetadata.$t = markType(FormatGroupTextEventArgsDescriptionMetadata, 'FormatGroupTextEventArgsDescriptionMetadata');
    FormatGroupTextEventArgsDescriptionMetadata.a = null;
    return FormatGroupTextEventArgsDescriptionMetadata;
}(Base));
export { FormatGroupTextEventArgsDescriptionMetadata };
